@@ -6,7 +6,7 @@ program test
   real, allocatable, dimension(:) :: x, y, xa, ya
   integer :: nx, er, i
   real :: a, cc, slope, intercept
-  real :: xmax, xmin, ymax, ymin, xmean, ymean
+  real :: xmax, xmin, ymax, ymin
   integer :: xmim, ymim, xmam, ymam
   character(1) :: alter
   character(8) :: ccn
@@ -33,17 +33,10 @@ program test
   end do
   close(unit=11,status='keep')
 
-  call Cor_Coe( x, y, cc )
-  call Reg_Line( x, y, slope, intercept )
-  call Mean_1d( x, xmean )
-  call Mean_1d( y, xmean )
-!  call Anomaly_1d( nx, x, xa )
-!  call Anomaly_1d( nx, y, ya )
-
-  do i=1,nx
-     xa(i)=x(i)/xmean
-     ya(i)=y(i)/ymean
-  end do
+  call Cor_Coe( nx, x, y, cc )
+  call Reg_Line( nx, x, y, slope, intercept )
+  call Anomaly_1d( nx, x, xa )
+  call Anomaly_1d( nx, y, ya )
 
   call max_val_1d(xa, xmam, xmax )
   call max_val_1d(ya, ymam, ymax )
