@@ -1,22 +1,24 @@
 program test
   use ffts
   implicit none
-  integer, parameter :: nx=8
-  real, parameter :: l=8.0
+  integer, parameter :: nx=10
+  real, parameter :: l=10.0
   real :: t(nx)
   real, parameter :: dt=1.0
-  complex :: x(nx), y(nx)
+  complex :: x(nx)
+  complex :: y(nx)
   real, parameter :: pi=3.14159265
   complex, parameter :: img=(0.0,1.0)
   integer :: i, j, k
 
   do i=1,nx
      t(i)=2.0*pi*dt*(i-1)/l
-     x(i)=sin(t(i))
+     x(i)=sin(-(t(i)-pi*dt*real(nx)/l)**2)
 !     x(i)=1.0
   end do
 
-  call ffttp_1d( nx, x, y, 'r', 'x' )
+  call ffttp_1d( nx, x, y, 'r', 'o' )
+  call ffttp_1d( nx, y, x, 'i', 'o' )
 
   do i=1,nx
      write(*,*) y(i)
